.highlight-chroma{color:#f8f8f2;background-color:#272822}.highlight-chroma .highlight-err{color:#960050;background-color:#1e0010}.highlight-chroma .highlight-lntd{vertical-align:top;padding:0;margin:0;border:0}.highlight-chroma .highlight-lntable{border-spacing:0;padding:0;margin:0;border:0;width:auto;overflow:auto;display:block}.highlight-chroma .highlight-hl{display:block;width:100%;background-color:#3c3d38}.highlight-chroma .highlight-ln,.highlight-chroma .highlight-lnt{margin-right:.4em;padding:0 .4em;color:#7f7f7f}.highlight-chroma .highlight-k,.highlight-chroma .highlight-kc,.highlight-chroma .highlight-kd{color:#66d9ef}.highlight-chroma .highlight-kn{color:#f92672}.highlight-chroma .highlight-kp,.highlight-chroma .highlight-kr,.highlight-chroma .highlight-kt{color:#66d9ef}.highlight-chroma .highlight-na,.highlight-chroma .highlight-nc{color:#a6e22e}.highlight-chroma .highlight-no{color:#66d9ef}.highlight-chroma .highlight-nd,.highlight-chroma .highlight-ne,.highlight-chroma .highlight-nf,.highlight-chroma .highlight-nx{color:#a6e22e}.highlight-chroma .highlight-nt{color:#f92672}.highlight-chroma .highlight-l{color:#ae81ff}.highlight-chroma .highlight-dl,.highlight-chroma .highlight-ld,.highlight-chroma .highlight-s,.highlight-chroma .highlight-s2,.highlight-chroma .highlight-sa,.highlight-chroma .highlight-sb,.highlight-chroma .highlight-sc,.highlight-chroma .highlight-sd{color:#e6db74}.highlight-chroma .highlight-se{color:#ae81ff}.highlight-chroma .highlight-s1,.highlight-chroma .highlight-sh,.highlight-chroma .highlight-si,.highlight-chroma .highlight-sr,.highlight-chroma .highlight-ss,.highlight-chroma .highlight-sx{color:#e6db74}.highlight-chroma .highlight-il,.highlight-chroma .highlight-m,.highlight-chroma .highlight-mb,.highlight-chroma .highlight-mf,.highlight-chroma .highlight-mh,.highlight-chroma .highlight-mi,.highlight-chroma .highlight-mo{color:#ae81ff}.highlight-chroma .highlight-o,.highlight-chroma .highlight-ow{color:#f92672}.highlight-chroma .highlight-c,.highlight-chroma .highlight-c1,.highlight-chroma .highlight-ch,.highlight-chroma .highlight-cm,.highlight-chroma .highlight-cp,.highlight-chroma .highlight-cpf,.highlight-chroma .highlight-cs{color:#75715e}.highlight-chroma .highlight-gd{color:#f92672}.highlight-chroma .highlight-ge{font-style:italic}.highlight-chroma .highlight-gi{color:#a6e22e}.highlight-chroma .highlight-gs{font-weight:700}.highlight-chroma .highlight-gu{color:#75715e}.hljs{display:block;overflow-x:auto;padding:.5em;background:#272822;color:#ddd}.hljs-keyword,.hljs-literal,.hljs-name,.hljs-selector-tag,.hljs-strong,.hljs-tag{color:#f92672}.hljs-code{color:#66d9ef}.hljs-class .hljs-title{color:#fff}.hljs-attribute,.hljs-link,.hljs-regexp,.hljs-symbol{color:#bf79db}.hljs-addition,.hljs-built_in,.hljs-builtin-name,.hljs-bullet,.hljs-emphasis,.hljs-section,.hljs-selector-attr,.hljs-selector-pseudo,.hljs-string,.hljs-subst,.hljs-template-tag,.hljs-template-variable,.hljs-title,.hljs-type,.hljs-variable{color:#a6e22e}.hljs-comment,.hljs-deletion,.hljs-meta,.hljs-quote{color:#75715e}.hljs-doctag,.hljs-keyword,.hljs-literal,.hljs-section,.hljs-selector-id,.hljs-selector-tag,.hljs-title,.hljs-type{font-weight:700}