/// <reference types="./types" />
import { MenuItem } from "./MenuItem";
export declare class Export extends MenuItem {
    element: HTMLElement;
    constructor(vditor: IVditor, menuItem: IMenuItem);
}
