.highlight-chroma{background-color:#fff}.highlight-chroma .highlight-err{color:#a61717}.highlight-chroma .highlight-lntd{vertical-align:top;padding:0;margin:0;border:0}.highlight-chroma .highlight-lntable{border-spacing:0;padding:0;margin:0;border:0;width:auto;overflow:auto;display:block}.highlight-chroma .highlight-hl{display:block;width:100%;background-color:#e5e5e5}.highlight-chroma .highlight-ln,.highlight-chroma .highlight-lnt{margin-right:.4em;padding:0 .4em;color:#7f7f7f}.highlight-chroma .highlight-k{color:#728e00}.highlight-chroma .highlight-kc{color:#00979d}.highlight-chroma .highlight-kd,.highlight-chroma .highlight-kn{color:#728e00}.highlight-chroma .highlight-kp,.highlight-chroma .highlight-kr,.highlight-chroma .highlight-kt{color:#00979d}.highlight-chroma .highlight-n,.highlight-chroma .highlight-na{color:#434f54}.highlight-chroma .highlight-nb{color:#728e00}.highlight-chroma .highlight-bp,.highlight-chroma .highlight-nc,.highlight-chroma .highlight-nd,.highlight-chroma .highlight-ne,.highlight-chroma .highlight-ni,.highlight-chroma .highlight-no{color:#434f54}.highlight-chroma .highlight-nf{color:#d35400}.highlight-chroma .highlight-fm,.highlight-chroma .highlight-nl,.highlight-chroma .highlight-nn{color:#434f54}.highlight-chroma .highlight-nx{color:#728e00}.highlight-chroma .highlight-nt,.highlight-chroma .highlight-nv,.highlight-chroma .highlight-py,.highlight-chroma .highlight-vc,.highlight-chroma .highlight-vg,.highlight-chroma .highlight-vi,.highlight-chroma .highlight-vm{color:#434f54}.highlight-chroma .highlight-dl,.highlight-chroma .highlight-s,.highlight-chroma .highlight-s1,.highlight-chroma .highlight-s2,.highlight-chroma .highlight-sa,.highlight-chroma .highlight-sb,.highlight-chroma .highlight-sc,.highlight-chroma .highlight-sd,.highlight-chroma .highlight-se,.highlight-chroma .highlight-sh,.highlight-chroma .highlight-si,.highlight-chroma .highlight-sr,.highlight-chroma .highlight-ss,.highlight-chroma .highlight-sx{color:#7f8c8d}.highlight-chroma .highlight-il,.highlight-chroma .highlight-m,.highlight-chroma .highlight-mb,.highlight-chroma .highlight-mf,.highlight-chroma .highlight-mh,.highlight-chroma .highlight-mi,.highlight-chroma .highlight-mo{color:#8a7b52}.highlight-chroma .highlight-o,.highlight-chroma .highlight-ow{color:#728e00}.highlight-chroma .highlight-c,.highlight-chroma .highlight-c1,.highlight-chroma .highlight-ch,.highlight-chroma .highlight-cm,.highlight-chroma .highlight-cs{color:#95a5a6}.highlight-chroma .highlight-cp,.highlight-chroma .highlight-cpf{color:#728e00}.hljs{display:block;overflow-x:auto;padding:.5em;background:#fff}.hljs,.hljs-subst{color:#434f54}.hljs-attribute,.hljs-doctag,.hljs-keyword,.hljs-name,.hljs-selector-tag{color:#00979d}.hljs-addition,.hljs-built_in,.hljs-bullet,.hljs-code,.hljs-literal{color:#d35400}.hljs-link,.hljs-regexp,.hljs-selector-attr,.hljs-selector-pseudo,.hljs-symbol,.hljs-template-variable,.hljs-variable{color:#00979d}.hljs-deletion,.hljs-quote,.hljs-selector-class,.hljs-selector-id,.hljs-string,.hljs-template-tag,.hljs-type{color:#005c5f}.hljs-section,.hljs-title{color:#800;font-weight:700}.hljs-comment{color:rgba(149,165,166,.8)}.hljs-meta-keyword{color:#728e00}.hljs-meta{color:#728e00;color:#434f54}.hljs-emphasis{font-style:italic}.hljs-strong{font-weight:700}.hljs-function{color:#728e00}.hljs-number{color:#8a7b52}