.highlight-chroma{background-color:#f0f0f0}.highlight-chroma .highlight-lntd{vertical-align:top;padding:0;margin:0;border:0}.highlight-chroma .highlight-lntable{border-spacing:0;padding:0;margin:0;border:0;width:auto;overflow:auto;display:block}.highlight-chroma .highlight-hl{display:block;width:100%;background-color:#d8d8d8}.highlight-chroma .highlight-ln,.highlight-chroma .highlight-lnt{margin-right:.4em;padding:0 .4em;color:#7f7f7f}.highlight-chroma .highlight-k,.highlight-chroma .highlight-kc,.highlight-chroma .highlight-kd,.highlight-chroma .highlight-kn{color:#007020;font-weight:700}.highlight-chroma .highlight-kp{color:#007020}.highlight-chroma .highlight-kr{color:#007020;font-weight:700}.highlight-chroma .highlight-kt{color:#902000}.highlight-chroma .highlight-na{color:#4070a0}.highlight-chroma .highlight-nb{color:#007020}.highlight-chroma .highlight-nc{color:#0e84b5;font-weight:700}.highlight-chroma .highlight-no{color:#60add5}.highlight-chroma .highlight-nd{color:#555;font-weight:700}.highlight-chroma .highlight-ni{color:#d55537;font-weight:700}.highlight-chroma .highlight-ne{color:#007020}.highlight-chroma .highlight-nf{color:#06287e}.highlight-chroma .highlight-nl{color:#002070;font-weight:700}.highlight-chroma .highlight-nn{color:#0e84b5;font-weight:700}.highlight-chroma .highlight-nt{color:#062873;font-weight:700}.highlight-chroma .highlight-nv{color:#bb60d5}.highlight-chroma .highlight-dl,.highlight-chroma .highlight-s,.highlight-chroma .highlight-sa,.highlight-chroma .highlight-sb,.highlight-chroma .highlight-sc{color:#4070a0}.highlight-chroma .highlight-sd{color:#4070a0;font-style:italic}.highlight-chroma .highlight-s2{color:#4070a0}.highlight-chroma .highlight-se{color:#4070a0;font-weight:700}.highlight-chroma .highlight-sh{color:#4070a0}.highlight-chroma .highlight-si{color:#70a0d0;font-style:italic}.highlight-chroma .highlight-sx{color:#c65d09}.highlight-chroma .highlight-sr{color:#235388}.highlight-chroma .highlight-s1{color:#4070a0}.highlight-chroma .highlight-ss{color:#517918}.highlight-chroma .highlight-il,.highlight-chroma .highlight-m,.highlight-chroma .highlight-mb,.highlight-chroma .highlight-mf,.highlight-chroma .highlight-mh,.highlight-chroma .highlight-mi,.highlight-chroma .highlight-mo{color:#40a070}.highlight-chroma .highlight-o{color:#666}.highlight-chroma .highlight-ow{color:#007020;font-weight:700}.highlight-chroma .highlight-c,.highlight-chroma .highlight-c1,.highlight-chroma .highlight-ch,.highlight-chroma .highlight-cm{color:#60a0b0;font-style:italic}.highlight-chroma .highlight-cs{color:#60a0b0;background-color:#fff0f0}.highlight-chroma .highlight-cp,.highlight-chroma .highlight-cpf{color:#007020}.highlight-chroma .highlight-gd{color:#a00000}.highlight-chroma .highlight-ge{font-style:italic}.highlight-chroma .highlight-gr{color:red}.highlight-chroma .highlight-gh{color:navy;font-weight:700}.highlight-chroma .highlight-gi{color:#00a000}.highlight-chroma .highlight-go{color:#888}.highlight-chroma .highlight-gp{color:#c65d09;font-weight:700}.highlight-chroma .highlight-gs{font-weight:700}.highlight-chroma .highlight-gu{color:purple;font-weight:700}.highlight-chroma .highlight-gt{color:#04d}.highlight-chroma .highlight-gl{text-decoration:underline}.highlight-chroma .highlight-w{color:#bbb}.hljs{display:block;overflow-x:auto;padding:.5em;background:#fff}.hljs,.hljs-subst{color:#000}.hljs-comment{color:#555;font-style:italic}.hljs-attribute,.hljs-doctag,.hljs-keyword,.hljs-meta-keyword,.hljs-name,.hljs-selector-tag{color:#000;font-weight:700}.hljs-string{color:navy}.hljs-deletion,.hljs-number,.hljs-quote,.hljs-selector-class,.hljs-selector-id,.hljs-template-tag,.hljs-type{color:#000}.hljs-section,.hljs-title{color:#fb2c00}.hljs-title>.hljs-built_in{color:teal;font-weight:400}.hljs-link,.hljs-regexp,.hljs-selector-attr,.hljs-selector-pseudo,.hljs-symbol,.hljs-template-variable,.hljs-variable{color:#5e1700}.hljs-built_in,.hljs-literal{color:navy;font-weight:700}.hljs-addition,.hljs-bullet,.hljs-code{color:#397300}.hljs-class{color:#6f1c00;font-weight:700}.hljs-meta{color:#1f7199}.hljs-meta-string{color:#4d99bf}.hljs-emphasis{font-style:italic}.hljs-strong{font-weight:700}