.highlight-chroma{background-color:#fff}.highlight-chroma .highlight-err{color:#a61717;background-color:#e3d2d2}.highlight-chroma .highlight-lntd{vertical-align:top;padding:0;margin:0;border:0}.highlight-chroma .highlight-lntable{border-spacing:0;padding:0;margin:0;border:0;width:auto;overflow:auto;display:block}.highlight-chroma .highlight-hl{display:block;width:100%;background-color:#e5e5e5}.highlight-chroma .highlight-ln,.highlight-chroma .highlight-lnt{margin-right:.4em;padding:0 .4em;color:#7f7f7f}.highlight-chroma .highlight-k,.highlight-chroma .highlight-kc,.highlight-chroma .highlight-kd,.highlight-chroma .highlight-kn,.highlight-chroma .highlight-kp,.highlight-chroma .highlight-kr,.highlight-chroma .highlight-kt{color:navy;font-weight:700}.highlight-chroma .highlight-na{color:red}.highlight-chroma .highlight-nt{color:navy;font-weight:700}.highlight-chroma .highlight-s,.highlight-chroma .highlight-sa,.highlight-chroma .highlight-sb{color:#00f}.highlight-chroma .highlight-sc{color:purple}.highlight-chroma .highlight-dl,.highlight-chroma .highlight-il,.highlight-chroma .highlight-m,.highlight-chroma .highlight-mb,.highlight-chroma .highlight-mf,.highlight-chroma .highlight-mh,.highlight-chroma .highlight-mi,.highlight-chroma .highlight-mo,.highlight-chroma .highlight-s1,.highlight-chroma .highlight-s2,.highlight-chroma .highlight-sd,.highlight-chroma .highlight-se,.highlight-chroma .highlight-sh,.highlight-chroma .highlight-si,.highlight-chroma .highlight-sr,.highlight-chroma .highlight-ss,.highlight-chroma .highlight-sx{color:#00f}.highlight-chroma .highlight-ow{font-weight:700}.highlight-chroma .highlight-c,.highlight-chroma .highlight-c1,.highlight-chroma .highlight-ch,.highlight-chroma .highlight-cm{color:#080;font-style:italic}.highlight-chroma .highlight-cs{color:#080;font-weight:700}.highlight-chroma .highlight-cp,.highlight-chroma .highlight-cpf{color:teal}.highlight-chroma .highlight-gd{color:#000;background-color:#fdd}.highlight-chroma .highlight-ge{font-style:italic}.highlight-chroma .highlight-gr{color:#a00}.highlight-chroma .highlight-gh{color:#999}.highlight-chroma .highlight-gi{color:#000;background-color:#dfd}.highlight-chroma .highlight-go{color:#888}.highlight-chroma .highlight-gp{color:#555}.highlight-chroma .highlight-gs{font-weight:700}.highlight-chroma .highlight-gu{color:#aaa}.highlight-chroma .highlight-gt{color:#a00}.highlight-chroma .highlight-gl{text-decoration:underline}.highlight-chroma .highlight-w{color:#bbb}.hljs{display:block;overflow-x:auto;padding:.5em}.hljs-name{color:#01a3a3}.hljs-meta,.hljs-tag{color:#789}.hljs,.hljs-subst{color:#444}.hljs-comment{color:#888}.hljs-attribute,.hljs-doctag,.hljs-keyword,.hljs-meta-keyword,.hljs-name,.hljs-selector-tag{font-weight:700}.hljs-deletion,.hljs-number,.hljs-quote,.hljs-selector-class,.hljs-selector-id,.hljs-string,.hljs-template-tag,.hljs-type{color:#4286f4}.hljs-section,.hljs-title{color:#4286f4;font-weight:700}.hljs-link,.hljs-regexp,.hljs-selector-attr,.hljs-selector-pseudo,.hljs-symbol,.hljs-template-variable,.hljs-variable{color:#bc6060}.hljs-literal{color:#62bcbc}.hljs-addition,.hljs-built_in,.hljs-bullet,.hljs-code{color:#25c6c6}.hljs-meta-string{color:#4d99bf}.hljs-emphasis{font-style:italic}.hljs-strong{font-weight:700}