.highlight-chroma{color:#8a8a8a;background-color:#1c1c1c}.highlight-chroma .highlight-x{color:#d75f00}.highlight-chroma .highlight-lntd{vertical-align:top;padding:0;margin:0;border:0}.highlight-chroma .highlight-lntable{border-spacing:0;padding:0;margin:0;border:0;width:auto;overflow:auto;display:block}.highlight-chroma .highlight-hl{display:block;width:100%;background-color:#323232}.highlight-chroma .highlight-ln,.highlight-chroma .highlight-lnt{margin-right:.4em;padding:0 .4em;color:#454545}.highlight-chroma .highlight-k{color:#5f8700}.highlight-chroma .highlight-kc{color:#d75f00}.highlight-chroma .highlight-kd{color:#0087ff}.highlight-chroma .highlight-kn{color:#d75f00}.highlight-chroma .highlight-kp{color:#5f8700}.highlight-chroma .highlight-kr{color:#0087ff}.highlight-chroma .highlight-kt{color:#af0000}.highlight-chroma .highlight-bp,.highlight-chroma .highlight-nb,.highlight-chroma .highlight-nc{color:#0087ff}.highlight-chroma .highlight-no{color:#d75f00}.highlight-chroma .highlight-nd{color:#0087ff}.highlight-chroma .highlight-ni{color:#d75f00}.highlight-chroma .highlight-ne{color:#af8700}.highlight-chroma .highlight-nf,.highlight-chroma .highlight-nt,.highlight-chroma .highlight-nv{color:#0087ff}.highlight-chroma .highlight-s,.highlight-chroma .highlight-sa{color:#00afaf}.highlight-chroma .highlight-sb{color:#4e4e4e}.highlight-chroma .highlight-dl,.highlight-chroma .highlight-s2,.highlight-chroma .highlight-sc,.highlight-chroma .highlight-sd{color:#00afaf}.highlight-chroma .highlight-se{color:#af0000}.highlight-chroma .highlight-sh,.highlight-chroma .highlight-si,.highlight-chroma .highlight-sx{color:#00afaf}.highlight-chroma .highlight-sr{color:#af0000}.highlight-chroma .highlight-il,.highlight-chroma .highlight-m,.highlight-chroma .highlight-mb,.highlight-chroma .highlight-mf,.highlight-chroma .highlight-mh,.highlight-chroma .highlight-mi,.highlight-chroma .highlight-mo,.highlight-chroma .highlight-s1,.highlight-chroma .highlight-ss{color:#00afaf}.highlight-chroma .highlight-ow{color:#5f8700}.highlight-chroma .highlight-c,.highlight-chroma .highlight-c1,.highlight-chroma .highlight-ch,.highlight-chroma .highlight-cm{color:#4e4e4e}.highlight-chroma .highlight-cp,.highlight-chroma .highlight-cpf,.highlight-chroma .highlight-cs{color:#5f8700}.highlight-chroma .highlight-gd{color:#af0000}.highlight-chroma .highlight-ge{font-style:italic}.highlight-chroma .highlight-gr{color:#af0000;font-weight:700}.highlight-chroma .highlight-gh{color:#d75f00}.highlight-chroma .highlight-gi{color:#5f8700}.highlight-chroma .highlight-gs{font-weight:700}.highlight-chroma .highlight-gu{color:#0087ff}.hljs-comment,.hljs-quote{color:#7e7887}.hljs-attribute,.hljs-link,.hljs-name,.hljs-regexp,.hljs-selector-class,.hljs-selector-id,.hljs-tag,.hljs-template-variable,.hljs-variable{color:#be4678}.hljs-built_in,.hljs-builtin-name,.hljs-literal,.hljs-meta,.hljs-number,.hljs-params,.hljs-type{color:#aa573c}.hljs-bullet,.hljs-string,.hljs-symbol{color:#2a9292}.hljs-section,.hljs-title{color:#576ddb}.hljs-keyword,.hljs-selector-tag{color:#955ae7}.hljs-addition,.hljs-deletion{color:#19171c;display:inline-block;width:100%}.hljs-deletion{background-color:#be4678}.hljs-addition{background-color:#2a9292}.hljs{display:block;overflow-x:auto;background:#19171c;color:#8b8792;padding:.5em}.hljs-emphasis{font-style:italic}.hljs-strong{font-weight:700}