.highlight-chroma{color:#e7e9db;background-color:#2f1e2e}.highlight-chroma .highlight-err{color:#ef6155}.highlight-chroma .highlight-lntd{vertical-align:top;padding:0;margin:0;border:0}.highlight-chroma .highlight-lntable{border-spacing:0;padding:0;margin:0;border:0;width:auto;overflow:auto;display:block}.highlight-chroma .highlight-hl{display:block;width:100%;background-color:#433442}.highlight-chroma .highlight-ln,.highlight-chroma .highlight-lnt{margin-right:.4em;padding:0 .4em;color:#7f7f7f}.highlight-chroma .highlight-k,.highlight-chroma .highlight-kc,.highlight-chroma .highlight-kd{color:#815ba4}.highlight-chroma .highlight-kn{color:#5bc4bf}.highlight-chroma .highlight-kp,.highlight-chroma .highlight-kr{color:#815ba4}.highlight-chroma .highlight-kt{color:#fec418}.highlight-chroma .highlight-na{color:#06b6ef}.highlight-chroma .highlight-nc{color:#fec418}.highlight-chroma .highlight-no{color:#ef6155}.highlight-chroma .highlight-nd{color:#5bc4bf}.highlight-chroma .highlight-ne{color:#ef6155}.highlight-chroma .highlight-nf{color:#06b6ef}.highlight-chroma .highlight-nn{color:#fec418}.highlight-chroma .highlight-nx{color:#06b6ef}.highlight-chroma .highlight-nt{color:#5bc4bf}.highlight-chroma .highlight-nv{color:#ef6155}.highlight-chroma .highlight-l{color:#f99b15}.highlight-chroma .highlight-dl,.highlight-chroma .highlight-ld,.highlight-chroma .highlight-s,.highlight-chroma .highlight-sa,.highlight-chroma .highlight-sb{color:#48b685}.highlight-chroma .highlight-sd{color:#776e71}.highlight-chroma .highlight-s2{color:#48b685}.highlight-chroma .highlight-se{color:#f99b15}.highlight-chroma .highlight-sh{color:#48b685}.highlight-chroma .highlight-si{color:#f99b15}.highlight-chroma .highlight-s1,.highlight-chroma .highlight-sr,.highlight-chroma .highlight-ss,.highlight-chroma .highlight-sx{color:#48b685}.highlight-chroma .highlight-il,.highlight-chroma .highlight-m,.highlight-chroma .highlight-mb,.highlight-chroma .highlight-mf,.highlight-chroma .highlight-mh,.highlight-chroma .highlight-mi,.highlight-chroma .highlight-mo{color:#f99b15}.highlight-chroma .highlight-o,.highlight-chroma .highlight-ow{color:#5bc4bf}.highlight-chroma .highlight-c,.highlight-chroma .highlight-c1,.highlight-chroma .highlight-ch,.highlight-chroma .highlight-cm,.highlight-chroma .highlight-cp,.highlight-chroma .highlight-cpf,.highlight-chroma .highlight-cs{color:#776e71}.highlight-chroma .highlight-gd{color:#ef6155}.highlight-chroma .highlight-ge{font-style:italic}.highlight-chroma .highlight-gh{font-weight:700}.highlight-chroma .highlight-gi{color:#48b685}.highlight-chroma .highlight-gp{color:#776e71;font-weight:700}.highlight-chroma .highlight-gs{font-weight:700}.highlight-chroma .highlight-gu{color:#5bc4bf;font-weight:700}.hljs-comment,.hljs-quote{color:#8d8687}.hljs-link,.hljs-meta,.hljs-name,.hljs-regexp,.hljs-selector-class,.hljs-selector-id,.hljs-tag,.hljs-template-variable,.hljs-variable{color:#ef6155}.hljs-built_in,.hljs-builtin-name,.hljs-deletion,.hljs-literal,.hljs-number,.hljs-params,.hljs-type{color:#f99b15}.hljs-attribute,.hljs-section,.hljs-title{color:#fec418}.hljs-addition,.hljs-bullet,.hljs-string,.hljs-symbol{color:#48b685}.hljs-keyword,.hljs-selector-tag{color:#815ba4}.hljs{display:block;overflow-x:auto;background:#2f1e2e;color:#a39e9b;padding:.5em}.hljs-emphasis{font-style:italic}.hljs-strong{font-weight:700}