.highlight-chroma{background-color:#f8f8f8}.highlight-chroma .highlight-x{color:#000}.highlight-chroma .highlight-err{color:#a40000}.highlight-chroma .highlight-lntd{vertical-align:top;padding:0;margin:0;border:0}.highlight-chroma .highlight-lntable{border-spacing:0;padding:0;margin:0;border:0;width:auto;overflow:auto;display:block}.highlight-chroma .highlight-hl{display:block;width:100%;background-color:#dfdfdf}.highlight-chroma .highlight-ln,.highlight-chroma .highlight-lnt{margin-right:.4em;padding:0 .4em;color:#7f7f7f}.highlight-chroma .highlight-k,.highlight-chroma .highlight-kc,.highlight-chroma .highlight-kd,.highlight-chroma .highlight-kn,.highlight-chroma .highlight-kp,.highlight-chroma .highlight-kr,.highlight-chroma .highlight-kt{color:#204a87;font-weight:700}.highlight-chroma .highlight-n{color:#000}.highlight-chroma .highlight-na{color:#c4a000}.highlight-chroma .highlight-nb{color:#204a87}.highlight-chroma .highlight-bp{color:#3465a4}.highlight-chroma .highlight-nc,.highlight-chroma .highlight-no{color:#000}.highlight-chroma .highlight-nd{color:#5c35cc;font-weight:700}.highlight-chroma .highlight-ni{color:#ce5c00}.highlight-chroma .highlight-ne{color:#c00;font-weight:700}.highlight-chroma .highlight-fm,.highlight-chroma .highlight-nf{color:#000}.highlight-chroma .highlight-nl{color:#f57900}.highlight-chroma .highlight-nn,.highlight-chroma .highlight-nx,.highlight-chroma .highlight-py{color:#000}.highlight-chroma .highlight-nt{color:#204a87;font-weight:700}.highlight-chroma .highlight-l,.highlight-chroma .highlight-ld,.highlight-chroma .highlight-nv,.highlight-chroma .highlight-vc,.highlight-chroma .highlight-vg,.highlight-chroma .highlight-vi,.highlight-chroma .highlight-vm{color:#000}.highlight-chroma .highlight-dl,.highlight-chroma .highlight-s,.highlight-chroma .highlight-sa,.highlight-chroma .highlight-sb,.highlight-chroma .highlight-sc{color:#4e9a06}.highlight-chroma .highlight-sd{color:#8f5902;font-style:italic}.highlight-chroma .highlight-s1,.highlight-chroma .highlight-s2,.highlight-chroma .highlight-se,.highlight-chroma .highlight-sh,.highlight-chroma .highlight-si,.highlight-chroma .highlight-sr,.highlight-chroma .highlight-ss,.highlight-chroma .highlight-sx{color:#4e9a06}.highlight-chroma .highlight-il,.highlight-chroma .highlight-m,.highlight-chroma .highlight-mb,.highlight-chroma .highlight-mf,.highlight-chroma .highlight-mh,.highlight-chroma .highlight-mi,.highlight-chroma .highlight-mo{color:#0000cf;font-weight:700}.highlight-chroma .highlight-o{color:#ce5c00;font-weight:700}.highlight-chroma .highlight-ow{color:#204a87;font-weight:700}.highlight-chroma .highlight-p{color:#000;font-weight:700}.highlight-chroma .highlight-c,.highlight-chroma .highlight-c1,.highlight-chroma .highlight-ch,.highlight-chroma .highlight-cm,.highlight-chroma .highlight-cp,.highlight-chroma .highlight-cpf,.highlight-chroma .highlight-cs{color:#8f5902;font-style:italic}.highlight-chroma .highlight-g{color:#000}.highlight-chroma .highlight-gd{color:#a40000}.highlight-chroma .highlight-ge{color:#000;font-style:italic}.highlight-chroma .highlight-gr{color:#ef2929}.highlight-chroma .highlight-gh{color:navy;font-weight:700}.highlight-chroma .highlight-gi{color:#00a000}.highlight-chroma .highlight-go{color:#000;font-style:italic}.highlight-chroma .highlight-gp{color:#8f5902}.highlight-chroma .highlight-gs{color:#000;font-weight:700}.highlight-chroma .highlight-gu{color:purple;font-weight:700}.highlight-chroma .highlight-gt{color:#a40000;font-weight:700}.highlight-chroma .highlight-gl{color:#000;text-decoration:underline}.highlight-chroma .highlight-w{color:#f8f8f8;text-decoration:underline}.hljs-comment,.hljs-quote{color:#696969}.hljs-deletion,.hljs-name,.hljs-regexp,.hljs-selector-class,.hljs-selector-id,.hljs-tag,.hljs-template-variable,.hljs-variable{color:#d91e18}.hljs-attribute,.hljs-built_in,.hljs-builtin-name,.hljs-link,.hljs-literal,.hljs-meta,.hljs-number,.hljs-params,.hljs-type{color:#aa5d00}.hljs-addition,.hljs-bullet,.hljs-string,.hljs-symbol{color:green}.hljs-section,.hljs-title{color:#007faa}.hljs-keyword,.hljs-selector-tag{color:#7928a1}.hljs{display:block;overflow-x:auto;background:#fefefe;color:#545454;padding:.5em}.hljs-emphasis{font-style:italic}.hljs-strong{font-weight:700}@media screen and (-ms-high-contrast:active){.hljs-addition,.hljs-attribute,.hljs-built_in,.hljs-builtin-name,.hljs-bullet,.hljs-comment,.hljs-link,.hljs-literal,.hljs-meta,.hljs-number,.hljs-params,.hljs-quote,.hljs-string,.hljs-symbol,.hljs-type{color:highlight}.hljs-keyword,.hljs-selector-tag{font-weight:700}}