.highlight-chroma{background-color:#fff}.highlight-chroma .highlight-err{color:red;background-color:#faa}.highlight-chroma .highlight-lntd{vertical-align:top;padding:0;margin:0;border:0}.highlight-chroma .highlight-lntable{border-spacing:0;padding:0;margin:0;border:0;width:auto;overflow:auto;display:block}.highlight-chroma .highlight-hl{display:block;width:100%;background-color:#e5e5e5}.highlight-chroma .highlight-ln,.highlight-chroma .highlight-lnt{margin-right:.4em;padding:0 .4em;color:#7f7f7f}.highlight-chroma .highlight-k,.highlight-chroma .highlight-kc,.highlight-chroma .highlight-kd,.highlight-chroma .highlight-kn,.highlight-chroma .highlight-kp,.highlight-chroma .highlight-kr{color:#00a}.highlight-chroma .highlight-kt{color:#0aa}.highlight-chroma .highlight-na{color:#1e90ff}.highlight-chroma .highlight-nb{color:#0aa}.highlight-chroma .highlight-nc{color:#0a0;text-decoration:underline}.highlight-chroma .highlight-no{color:#a00}.highlight-chroma .highlight-nd{color:#888}.highlight-chroma .highlight-ni{color:#800;font-weight:700}.highlight-chroma .highlight-nf{color:#0a0}.highlight-chroma .highlight-nn{color:#0aa;text-decoration:underline}.highlight-chroma .highlight-nt{color:#1e90ff;font-weight:700}.highlight-chroma .highlight-nv{color:#a00}.highlight-chroma .highlight-dl,.highlight-chroma .highlight-s,.highlight-chroma .highlight-s2,.highlight-chroma .highlight-sa,.highlight-chroma .highlight-sb,.highlight-chroma .highlight-sc,.highlight-chroma .highlight-sd,.highlight-chroma .highlight-se,.highlight-chroma .highlight-sh,.highlight-chroma .highlight-si,.highlight-chroma .highlight-sx{color:#a50}.highlight-chroma .highlight-sr{color:#099}.highlight-chroma .highlight-s1{color:#a50}.highlight-chroma .highlight-ss{color:#00a}.highlight-chroma .highlight-il,.highlight-chroma .highlight-m,.highlight-chroma .highlight-mb,.highlight-chroma .highlight-mf,.highlight-chroma .highlight-mh,.highlight-chroma .highlight-mi,.highlight-chroma .highlight-mo{color:#099}.highlight-chroma .highlight-ow{color:#00a}.highlight-chroma .highlight-c,.highlight-chroma .highlight-c1,.highlight-chroma .highlight-ch,.highlight-chroma .highlight-cm{color:#aaa;font-style:italic}.highlight-chroma .highlight-cs{color:#00a;font-style:italic}.highlight-chroma .highlight-cp,.highlight-chroma .highlight-cpf{color:#4c8317}.highlight-chroma .highlight-gd{color:#a00}.highlight-chroma .highlight-ge{font-style:italic}.highlight-chroma .highlight-gr{color:#a00}.highlight-chroma .highlight-gh{color:navy;font-weight:700}.highlight-chroma .highlight-gi{color:#0a0}.highlight-chroma .highlight-go{color:#888}.highlight-chroma .highlight-gp{color:#555}.highlight-chroma .highlight-gs{font-weight:700}.highlight-chroma .highlight-gu{color:purple;font-weight:700}.highlight-chroma .highlight-gt{color:#a00}.highlight-chroma .highlight-gl{text-decoration:underline}.highlight-chroma .highlight-w{color:#bbb}.hljs-comment,.hljs-quote{color:#776977}.hljs-attribute,.hljs-link,.hljs-name,.hljs-regexp,.hljs-selector-class,.hljs-selector-id,.hljs-tag,.hljs-template-variable,.hljs-variable{color:#ca402b}.hljs-built_in,.hljs-builtin-name,.hljs-literal,.hljs-meta,.hljs-number,.hljs-params,.hljs-type{color:#a65926}.hljs-bullet,.hljs-string,.hljs-symbol{color:#918b3b}.hljs-section,.hljs-title{color:#516aec}.hljs-keyword,.hljs-selector-tag{color:#7b59c0}.hljs{display:block;overflow-x:auto;background:#f7f3f7;color:#695d69;padding:.5em}.hljs-emphasis{font-style:italic}.hljs-strong{font-weight:700}