.highlight-chroma{background-color:#fff}.highlight-chroma .highlight-err{background-color:#a848a8}.highlight-chroma .highlight-lntd{vertical-align:top;padding:0;margin:0;border:0}.highlight-chroma .highlight-lntable{border-spacing:0;padding:0;margin:0;border:0;width:auto;overflow:auto;display:block}.highlight-chroma .highlight-hl{display:block;width:100%;background-color:#e5e5e5}.highlight-chroma .highlight-ln,.highlight-chroma .highlight-lnt{margin-right:.4em;padding:0 .4em;color:#7f7f7f}.highlight-chroma .highlight-k{color:#2838b0}.highlight-chroma .highlight-kc{color:#444;font-style:italic}.highlight-chroma .highlight-kd{color:#2838b0;font-style:italic}.highlight-chroma .highlight-kn,.highlight-chroma .highlight-kp,.highlight-chroma .highlight-kr{color:#2838b0}.highlight-chroma .highlight-kt{color:#2838b0;font-style:italic}.highlight-chroma .highlight-na,.highlight-chroma .highlight-nb{color:#388038}.highlight-chroma .highlight-bp{font-style:italic}.highlight-chroma .highlight-nc{color:#287088}.highlight-chroma .highlight-no{color:#b85820}.highlight-chroma .highlight-nd{color:#287088}.highlight-chroma .highlight-ni{color:#709030}.highlight-chroma .highlight-ne{color:#908828}.highlight-chroma .highlight-nf{color:#785840}.highlight-chroma .highlight-fm{color:#b85820}.highlight-chroma .highlight-nl,.highlight-chroma .highlight-nn{color:#289870}.highlight-chroma .highlight-nt{color:#2838b0}.highlight-chroma .highlight-nv{color:#b04040}.highlight-chroma .highlight-vg{color:#908828}.highlight-chroma .highlight-vm{color:#b85820}.highlight-chroma .highlight-s{color:#b83838}.highlight-chroma .highlight-sa{color:#444}.highlight-chroma .highlight-sb{color:#b83838}.highlight-chroma .highlight-sc{color:#a848a8}.highlight-chroma .highlight-dl{color:#b85820}.highlight-chroma .highlight-sd{color:#b85820;font-style:italic}.highlight-chroma .highlight-s2{color:#b83838}.highlight-chroma .highlight-se{color:#709030}.highlight-chroma .highlight-sh{color:#b83838}.highlight-chroma .highlight-si{color:#b83838;text-decoration:underline}.highlight-chroma .highlight-sr,.highlight-chroma .highlight-sx{color:#a848a8}.highlight-chroma .highlight-s1,.highlight-chroma .highlight-ss{color:#b83838}.highlight-chroma .highlight-il,.highlight-chroma .highlight-m,.highlight-chroma .highlight-mb,.highlight-chroma .highlight-mf,.highlight-chroma .highlight-mh,.highlight-chroma .highlight-mi,.highlight-chroma .highlight-mo{color:#444}.highlight-chroma .highlight-o{color:#666}.highlight-chroma .highlight-ow{color:#a848a8}.highlight-chroma .highlight-p{color:#888}.highlight-chroma .highlight-c{color:#888;font-style:italic}.highlight-chroma .highlight-ch{color:#287088;font-style:italic}.highlight-chroma .highlight-c1,.highlight-chroma .highlight-cm,.highlight-chroma .highlight-cs{color:#888;font-style:italic}.highlight-chroma .highlight-cp,.highlight-chroma .highlight-cpf{color:#289870}.highlight-chroma .highlight-gd{color:#c02828}.highlight-chroma .highlight-ge{font-style:italic}.highlight-chroma .highlight-gr{color:#c02828}.highlight-chroma .highlight-gh{color:#666}.highlight-chroma .highlight-gi{color:#388038}.highlight-chroma .highlight-go{color:#666}.highlight-chroma .highlight-gp{color:#444}.highlight-chroma .highlight-gs{font-weight:700}.highlight-chroma .highlight-gu{color:#444}.highlight-chroma .highlight-gt{color:#2838b0}.highlight-chroma .highlight-gl{text-decoration:underline}.highlight-chroma .highlight-w{color:#a89028}.hljs{display:block;overflow-x:auto;padding:.5em;background-color:#f4f4f4}.hljs,.hljs-subst{color:#000}.hljs-addition,.hljs-attribute,.hljs-bullet,.hljs-string,.hljs-symbol,.hljs-template-tag,.hljs-template-variable,.hljs-title,.hljs-variable{color:#050}.hljs-comment,.hljs-quote{color:#777}.hljs-link,.hljs-literal,.hljs-number,.hljs-regexp,.hljs-type{color:#800}.hljs-deletion,.hljs-meta{color:#00e}.hljs-built_in,.hljs-doctag,.hljs-keyword,.hljs-name,.hljs-section,.hljs-selector-tag,.hljs-tag,.hljs-title{font-weight:700;color:navy}.hljs-emphasis{font-style:italic}.hljs-strong{font-weight:700}