.highlight-chroma{color:#f8f8f2;background-color:#282a36}.highlight-chroma .highlight-lntd{vertical-align:top;padding:0;margin:0;border:0}.highlight-chroma .highlight-lntable{border-spacing:0;padding:0;margin:0;border:0;width:auto;overflow:auto;display:block}.highlight-chroma .highlight-hl{display:block;width:100%;background-color:#3d3f4a}.highlight-chroma .highlight-ln,.highlight-chroma .highlight-lnt{margin-right:.4em;padding:0 .4em;color:#7f7f7f}.highlight-chroma .highlight-k,.highlight-chroma .highlight-kc{color:#ff79c6}.highlight-chroma .highlight-kd{color:#8be9fd;font-style:italic}.highlight-chroma .highlight-kn,.highlight-chroma .highlight-kp,.highlight-chroma .highlight-kr{color:#ff79c6}.highlight-chroma .highlight-kt{color:#8be9fd}.highlight-chroma .highlight-na{color:#50fa7b}.highlight-chroma .highlight-nb{color:#8be9fd;font-style:italic}.highlight-chroma .highlight-nc,.highlight-chroma .highlight-nf{color:#50fa7b}.highlight-chroma .highlight-nl{color:#8be9fd;font-style:italic}.highlight-chroma .highlight-nt{color:#ff79c6}.highlight-chroma .highlight-nv,.highlight-chroma .highlight-vc,.highlight-chroma .highlight-vg,.highlight-chroma .highlight-vi{color:#8be9fd;font-style:italic}.highlight-chroma .highlight-dl,.highlight-chroma .highlight-s,.highlight-chroma .highlight-s1,.highlight-chroma .highlight-s2,.highlight-chroma .highlight-sa,.highlight-chroma .highlight-sb,.highlight-chroma .highlight-sc,.highlight-chroma .highlight-sd,.highlight-chroma .highlight-se,.highlight-chroma .highlight-sh,.highlight-chroma .highlight-si,.highlight-chroma .highlight-sr,.highlight-chroma .highlight-ss,.highlight-chroma .highlight-sx{color:#f1fa8c}.highlight-chroma .highlight-il,.highlight-chroma .highlight-m,.highlight-chroma .highlight-mb,.highlight-chroma .highlight-mf,.highlight-chroma .highlight-mh,.highlight-chroma .highlight-mi,.highlight-chroma .highlight-mo{color:#bd93f9}.highlight-chroma .highlight-o,.highlight-chroma .highlight-ow{color:#ff79c6}.highlight-chroma .highlight-c,.highlight-chroma .highlight-c1,.highlight-chroma .highlight-ch,.highlight-chroma .highlight-cm,.highlight-chroma .highlight-cs{color:#6272a4}.highlight-chroma .highlight-cp,.highlight-chroma .highlight-cpf{color:#ff79c6}.highlight-chroma .highlight-gd{color:#8b080b}.highlight-chroma .highlight-ge{text-decoration:underline}.highlight-chroma .highlight-gh,.highlight-chroma .highlight-gi{font-weight:700}.highlight-chroma .highlight-go{color:#44475a}.highlight-chroma .highlight-gu{font-weight:700}.highlight-chroma .highlight-gl{text-decoration:underline}.hljs{display:block;overflow-x:auto;padding:.5em;background:#2b2b2b;color:#bababa}.hljs-emphasis,.hljs-strong{color:#a8a8a2}.hljs-bullet,.hljs-link,.hljs-literal,.hljs-number,.hljs-quote,.hljs-regexp{color:#6896ba}.hljs-code,.hljs-selector-class{color:#a6e22e}.hljs-emphasis{font-style:italic}.hljs-attribute,.hljs-keyword,.hljs-name,.hljs-section,.hljs-selector-tag,.hljs-variable{color:#cb7832}.hljs-params{color:#b9b9b9}.hljs-string{color:#6a8759}.hljs-addition,.hljs-built_in,.hljs-builtin-name,.hljs-selector-attr,.hljs-selector-id,.hljs-selector-pseudo,.hljs-subst,.hljs-symbol,.hljs-template-tag,.hljs-template-variable,.hljs-type{color:#e0c46c}.hljs-comment,.hljs-deletion,.hljs-meta{color:#7f7f7f}