.highlight-chroma{color:#93a1a1;background-color:#002b36}.highlight-chroma .highlight-x{color:#cb4b16}.highlight-chroma .highlight-lntd{vertical-align:top;padding:0;margin:0;border:0}.highlight-chroma .highlight-lntable{border-spacing:0;padding:0;margin:0;border:0;width:auto;overflow:auto;display:block}.highlight-chroma .highlight-hl{display:block;width:100%;background-color:#19404a}.highlight-chroma .highlight-ln,.highlight-chroma .highlight-lnt{margin-right:.4em;padding:0 .4em;color:#495050}.highlight-chroma .highlight-k{color:#719e07}.highlight-chroma .highlight-kc{color:#cb4b16}.highlight-chroma .highlight-kd{color:#268bd2}.highlight-chroma .highlight-kn,.highlight-chroma .highlight-kp{color:#719e07}.highlight-chroma .highlight-kr{color:#268bd2}.highlight-chroma .highlight-kt{color:#dc322f}.highlight-chroma .highlight-nb{color:#b58900}.highlight-chroma .highlight-bp,.highlight-chroma .highlight-nc{color:#268bd2}.highlight-chroma .highlight-no{color:#cb4b16}.highlight-chroma .highlight-nd{color:#268bd2}.highlight-chroma .highlight-ne,.highlight-chroma .highlight-ni{color:#cb4b16}.highlight-chroma .highlight-nf,.highlight-chroma .highlight-nt,.highlight-chroma .highlight-nv{color:#268bd2}.highlight-chroma .highlight-s,.highlight-chroma .highlight-sa{color:#2aa198}.highlight-chroma .highlight-sb{color:#586e75}.highlight-chroma .highlight-dl,.highlight-chroma .highlight-s2,.highlight-chroma .highlight-sc{color:#2aa198}.highlight-chroma .highlight-se{color:#cb4b16}.highlight-chroma .highlight-si,.highlight-chroma .highlight-sx{color:#2aa198}.highlight-chroma .highlight-sr{color:#dc322f}.highlight-chroma .highlight-il,.highlight-chroma .highlight-m,.highlight-chroma .highlight-mb,.highlight-chroma .highlight-mf,.highlight-chroma .highlight-mh,.highlight-chroma .highlight-mi,.highlight-chroma .highlight-mo,.highlight-chroma .highlight-s1,.highlight-chroma .highlight-ss{color:#2aa198}.highlight-chroma .highlight-o,.highlight-chroma .highlight-ow{color:#719e07}.highlight-chroma .highlight-c,.highlight-chroma .highlight-c1,.highlight-chroma .highlight-ch,.highlight-chroma .highlight-cm{color:#586e75}.highlight-chroma .highlight-cp,.highlight-chroma .highlight-cpf,.highlight-chroma .highlight-cs{color:#719e07}.highlight-chroma .highlight-gd{color:#dc322f}.highlight-chroma .highlight-ge{font-style:italic}.highlight-chroma .highlight-gr{color:#dc322f;font-weight:700}.highlight-chroma .highlight-gh{color:#cb4b16}.highlight-chroma .highlight-gi{color:#719e07}.highlight-chroma .highlight-gs{font-weight:700}.highlight-chroma .highlight-gu{color:#268bd2}.hljs{display:block;overflow-x:auto;padding:.5em;background:#002b36;color:#839496}.hljs-comment,.hljs-quote{color:#586e75}.hljs-addition,.hljs-keyword,.hljs-selector-tag{color:#859900}.hljs-doctag,.hljs-literal,.hljs-meta .hljs-meta-string,.hljs-number,.hljs-regexp,.hljs-string{color:#2aa198}.hljs-name,.hljs-section,.hljs-selector-class,.hljs-selector-id,.hljs-title{color:#268bd2}.hljs-attr,.hljs-attribute,.hljs-class .hljs-title,.hljs-template-variable,.hljs-type,.hljs-variable{color:#b58900}.hljs-bullet,.hljs-link,.hljs-meta,.hljs-meta .hljs-keyword,.hljs-selector-attr,.hljs-selector-pseudo,.hljs-subst,.hljs-symbol{color:#cb4b16}.hljs-built_in,.hljs-deletion{color:#dc322f}.hljs-formula{background:#073642}.hljs-emphasis{font-style:italic}.hljs-strong{font-weight:700}