.highlight-chroma{background-color:#fff}.highlight-chroma .highlight-err{color:red;background-color:#faa}.highlight-chroma .highlight-lntd{vertical-align:top;padding:0;margin:0;border:0}.highlight-chroma .highlight-lntable{border-spacing:0;padding:0;margin:0;border:0;width:auto;overflow:auto;display:block}.highlight-chroma .highlight-hl{display:block;width:100%;background-color:#e5e5e5}.highlight-chroma .highlight-ln,.highlight-chroma .highlight-lnt{margin-right:.4em;padding:0 .4em;color:#7f7f7f}.highlight-chroma .highlight-k,.highlight-chroma .highlight-kc,.highlight-chroma .highlight-kd,.highlight-chroma .highlight-kn{color:#080;font-weight:700}.highlight-chroma .highlight-kp{color:#038;font-weight:700}.highlight-chroma .highlight-kr{color:#080;font-weight:700}.highlight-chroma .highlight-kt{color:#339;font-weight:700}.highlight-chroma .highlight-na{color:#00c}.highlight-chroma .highlight-nb{color:#007020}.highlight-chroma .highlight-nc{color:#b06;font-weight:700}.highlight-chroma .highlight-no{color:#036;font-weight:700}.highlight-chroma .highlight-nd{color:#555;font-weight:700}.highlight-chroma .highlight-ni{color:#800;font-weight:700}.highlight-chroma .highlight-ne{color:red;font-weight:700}.highlight-chroma .highlight-nf{color:#06b;font-weight:700}.highlight-chroma .highlight-nl{color:#970;font-weight:700}.highlight-chroma .highlight-nn{color:#0e84b5;font-weight:700}.highlight-chroma .highlight-nt{color:#070}.highlight-chroma .highlight-nv{color:#963}.highlight-chroma .highlight-vc{color:#369}.highlight-chroma .highlight-vg{color:#d70;font-weight:700}.highlight-chroma .highlight-vi{color:#33b}.highlight-chroma .highlight-s,.highlight-chroma .highlight-sa,.highlight-chroma .highlight-sb{background-color:#fff0f0}.highlight-chroma .highlight-sc{color:#04d;background-color:#fff0f0}.highlight-chroma .highlight-dl{background-color:#fff0f0}.highlight-chroma .highlight-sd{color:#d42;background-color:#fff0f0}.highlight-chroma .highlight-s2{background-color:#fff0f0}.highlight-chroma .highlight-se{color:#666;background-color:#fff0f0;font-weight:700}.highlight-chroma .highlight-sh{background-color:#fff0f0}.highlight-chroma .highlight-si{background-color:#eee}.highlight-chroma .highlight-sx{color:#d20;background-color:#fff0f0}.highlight-chroma .highlight-sr{color:#000;background-color:#fff0ff}.highlight-chroma .highlight-s1{background-color:#fff0f0}.highlight-chroma .highlight-ss{color:#a60;background-color:#fff0f0}.highlight-chroma .highlight-m,.highlight-chroma .highlight-mb,.highlight-chroma .highlight-mf{color:#60e;font-weight:700}.highlight-chroma .highlight-mh{color:#058;font-weight:700}.highlight-chroma .highlight-mi{color:#00d;font-weight:700}.highlight-chroma .highlight-il{color:#60e;font-weight:700}.highlight-chroma .highlight-mo{color:#40e;font-weight:700}.highlight-chroma .highlight-o{color:#333}.highlight-chroma .highlight-ow{color:#000;font-weight:700}.highlight-chroma .highlight-c,.highlight-chroma .highlight-c1,.highlight-chroma .highlight-ch,.highlight-chroma .highlight-cm{color:#888}.highlight-chroma .highlight-cs{color:#c00;font-weight:700}.highlight-chroma .highlight-cp,.highlight-chroma .highlight-cpf{color:#579}.highlight-chroma .highlight-gd{color:#a00000}.highlight-chroma .highlight-ge{font-style:italic}.highlight-chroma .highlight-gr{color:red}.highlight-chroma .highlight-gh{color:navy;font-weight:700}.highlight-chroma .highlight-gi{color:#00a000}.highlight-chroma .highlight-go{color:#888}.highlight-chroma .highlight-gp{color:#c65d09;font-weight:700}.highlight-chroma .highlight-gs{font-weight:700}.highlight-chroma .highlight-gu{color:purple;font-weight:700}.highlight-chroma .highlight-gt{color:#04d}.highlight-chroma .highlight-gl{text-decoration:underline}.highlight-chroma .highlight-w{color:#bbb}.hljs-comment,.hljs-quote{color:#655d5d}.hljs-attribute,.hljs-link,.hljs-name,.hljs-regexp,.hljs-selector-class,.hljs-selector-id,.hljs-tag,.hljs-template-variable,.hljs-variable{color:#ca4949}.hljs-built_in,.hljs-builtin-name,.hljs-literal,.hljs-meta,.hljs-number,.hljs-params,.hljs-type{color:#b45a3c}.hljs-bullet,.hljs-string,.hljs-symbol{color:#4b8b8b}.hljs-section,.hljs-title{color:#7272ca}.hljs-keyword,.hljs-selector-tag{color:#8464c4}.hljs-addition,.hljs-deletion{color:#1b1818;display:inline-block;width:100%}.hljs-deletion{background-color:#ca4949}.hljs-addition{background-color:#4b8b8b}.hljs{display:block;overflow-x:auto;background:#f4ecec;color:#585050;padding:.5em}.hljs-emphasis{font-style:italic}.hljs-strong{font-weight:700}