.highlight-chroma{color:#586e75;background-color:#eee8d5}.highlight-chroma .highlight-lntd{vertical-align:top;padding:0;margin:0;border:0}.highlight-chroma .highlight-lntable{border-spacing:0;padding:0;margin:0;border:0;width:auto;overflow:auto;display:block}.highlight-chroma .highlight-hl{display:block;width:100%;background-color:#d6d0bf}.highlight-chroma .highlight-ln,.highlight-chroma .highlight-lnt{margin-right:.4em;padding:0 .4em;color:#7f7f7f}.highlight-chroma .highlight-k{color:#859900}.highlight-chroma .highlight-kc{color:#859900;font-weight:700}.highlight-chroma .highlight-kd{color:#859900}.highlight-chroma .highlight-kn{color:#dc322f;font-weight:700}.highlight-chroma .highlight-kp,.highlight-chroma .highlight-kr{color:#859900}.highlight-chroma .highlight-kt{color:#859900;font-weight:700}.highlight-chroma .highlight-n,.highlight-chroma .highlight-na{color:#268bd2}.highlight-chroma .highlight-nb{color:#cb4b16}.highlight-chroma .highlight-bp{color:#268bd2}.highlight-chroma .highlight-nc{color:#cb4b16}.highlight-chroma .highlight-fm,.highlight-chroma .highlight-nd,.highlight-chroma .highlight-ne,.highlight-chroma .highlight-nf,.highlight-chroma .highlight-ni,.highlight-chroma .highlight-nl,.highlight-chroma .highlight-nn,.highlight-chroma .highlight-no,.highlight-chroma .highlight-nx,.highlight-chroma .highlight-py{color:#268bd2}.highlight-chroma .highlight-nt{color:#268bd2;font-weight:700}.highlight-chroma .highlight-nv,.highlight-chroma .highlight-vc,.highlight-chroma .highlight-vg,.highlight-chroma .highlight-vi,.highlight-chroma .highlight-vm{color:#268bd2}.highlight-chroma .highlight-dl,.highlight-chroma .highlight-l,.highlight-chroma .highlight-ld,.highlight-chroma .highlight-s,.highlight-chroma .highlight-s1,.highlight-chroma .highlight-s2,.highlight-chroma .highlight-sa,.highlight-chroma .highlight-sb,.highlight-chroma .highlight-sc,.highlight-chroma .highlight-sd,.highlight-chroma .highlight-se,.highlight-chroma .highlight-sh,.highlight-chroma .highlight-si,.highlight-chroma .highlight-sr,.highlight-chroma .highlight-ss,.highlight-chroma .highlight-sx{color:#2aa198}.highlight-chroma .highlight-il,.highlight-chroma .highlight-m,.highlight-chroma .highlight-mb,.highlight-chroma .highlight-mf,.highlight-chroma .highlight-mh,.highlight-chroma .highlight-mi,.highlight-chroma .highlight-mo{color:#2aa198;font-weight:700}.highlight-chroma .highlight-ow{color:#859900}.highlight-chroma .highlight-c,.highlight-chroma .highlight-c1,.highlight-chroma .highlight-ch,.highlight-chroma .highlight-cm,.highlight-chroma .highlight-cp,.highlight-chroma .highlight-cpf,.highlight-chroma .highlight-cs{color:#93a1a1;font-style:italic}.highlight-chroma .highlight-g,.highlight-chroma .highlight-gd,.highlight-chroma .highlight-ge,.highlight-chroma .highlight-gh,.highlight-chroma .highlight-gi,.highlight-chroma .highlight-gl,.highlight-chroma .highlight-go,.highlight-chroma .highlight-gp,.highlight-chroma .highlight-gr,.highlight-chroma .highlight-gs,.highlight-chroma .highlight-gt,.highlight-chroma .highlight-gu{color:#d33682}.hljs{display:block;overflow-x:auto;padding:.5em;background:#fdf6e3;color:#657b83}.hljs-comment,.hljs-quote{color:#93a1a1}.hljs-addition,.hljs-keyword,.hljs-selector-tag{color:#859900}.hljs-doctag,.hljs-literal,.hljs-meta .hljs-meta-string,.hljs-number,.hljs-regexp,.hljs-string{color:#2aa198}.hljs-name,.hljs-section,.hljs-selector-class,.hljs-selector-id,.hljs-title{color:#268bd2}.hljs-attr,.hljs-attribute,.hljs-class .hljs-title,.hljs-template-variable,.hljs-type,.hljs-variable{color:#b58900}.hljs-bullet,.hljs-link,.hljs-meta,.hljs-meta .hljs-keyword,.hljs-selector-attr,.hljs-selector-pseudo,.hljs-subst,.hljs-symbol{color:#cb4b16}.hljs-built_in,.hljs-deletion{color:#dc322f}.hljs-formula{background:#eee8d5}.hljs-emphasis{font-style:italic}.hljs-strong{font-weight:700}